#!/bin/bash

if [ -f install.log ]
then
	rm install.log
fi
if [ -f error.log ]
then
	rm error.log
fi

echo Starting installation
if [ "$UID" -ne 0 ]
then
	echo
	echo You have to run this script as root.
	echo Try running the script with
	echo
	echo sudo ./install.sh
	echo
	echo Installation canceled
	echo
	exit 1
fi

echo -n Creating necessary directories...
if [ ! -d /usr/local/bin ]
then
	mkdir -v /usr/local/bin >> install.log 2>> error.log 
fi
if [ ! -d /usr/local/share/asus_osd ]
then
	mkdir -v /usr/local/share/asus_osd >> install.log 2>> error.log
fi
if [ ! -d /etc/acpi ]
then
	mkdir -v /etc/acpi >> install.log 2>> error.log
fi
if [ ! -d /etc/acpi/events ]
then
	mkdir -v /etc/acpi/events >> install.log 2>> error.log
fi
if [ ! -d $HOME/.config/autostart ]
then
	mkdir -v $HOME/.config/autostart >> install.log 2>> error.log
fi
echo done

echo -n Checking/removing older version files...
if [ `ps aux | grep -c asusosd` -gt 1 ]
then
	killall -v asusosd >> install.log 2>> error.log
fi
if [ -f /usr/local/bin/volume_control.sh ]
then
	rm -v /usr/local/bin/volume_control.sh >> install.log 2>> error.log
fi
if [ -f /etc/acpi/volupbtn.sh ]
then
	rm -v /etc/acpi/volupbtn.sh >> install.log 2>> error.log
fi
if [ -f /etc/acpi/voldownbtn.sh ]
then
	rm -v /etc/acpi/voldownbtn.sh >> install.log 2>> error.log
fi
if [ -f /etc/acpi/mutebtn.sh ]
then
	rm -v /etc/acpi/mutebtn.sh >> install.log 2>> error.log
fi
echo done

echo -n Setting directory permissions...
chmod -v 755 /usr/local/bin >> install.log 2>> error.log
chmod -v 755 /usr/local/share/asus_osd >> install.log 2>> error.log
chmod -v 755 /etc/acpi >> install.log 2>> error.log
chmod -v 755 /etc/acpi/events >> install.log 2>> error.log
chmod -v 777 $HOME/.config/autostart >> install.log 2>> error.log
echo done

echo -n Copying files...
cp -v autostart/ASUS-OSD.desktop $HOME/.config/autostart/ >> install.log 2>> error.log
cp -v ressources/* /usr/local/share/asus_osd/ >> install.log 2>> error.log
cp -v binaries/asusosd /usr/local/bin/ >> install.log 2>> error.log
cp -v events/* /etc/acpi/events/ >> install.log 2>> error.log
cp -v scripts/asus-brn-down.sh /etc/acpi/ >> install.log 2>> error.log
cp -v scripts/asus-brn-up.sh /etc/acpi/ >> install.log 2>> error.log
cp -v scripts/eee-wifi-on-off.sh /etc/acpi/ >> install.log 2>> error.log
cp -v scripts/queryvolume.sh /etc/acpi/ >> install.log 2>> error.log
echo done

echo -n Setting permissions...
chmod -v 644 $HOME/.config/autostart/ASUS-OSD.desktop >> install.log 2>> error.log
chmod -v 644 /usr/local/share/asus_osd/* >> install.log 2>> error.log
chmod -v 755 /usr/local/bin/asusosd >> install.log 2>> error.log
chmod -v 644 /etc/acpi/events/eee* >> install.log 2>> error.log
chmod -v 755 /etc/acpi/asus-brn-down.sh >> install.log 2>> error.log
chmod -v 755 /etc/acpi/asus-brn-up.sh >> install.log 2>> error.log
chmod -v 755 /etc/acpi/eee-wifi-on-off.sh >> install.log 2>> error.log
chmod -v 755 /etc/acpi/queryvolume.sh >> install.log 2>> error.log
echo done

echo Installation finished
echo 
echo You should reboot now in order to make the script load.
echo Make sure you close running apps and then type
echo 
echo sudo reboot now
echo
